Changelog
=========

Here you can see the full list of changes between each ``monoseq`` release.


Version 1.2.0
-------------

Released on May 10th 2015.

- `monoseq.ipynb.Seq` for use in the IPython Notebook.


Version 1.1.1
-------------

Released on July 18th 2013.

- Actually support 10 annotation levels in `HtmlFormat` as documented.
- User guide and documentation for command line interface.


Version 1.1.0
-------------

Released on July 14th 2013.

- Read annotation from BED track.
- Better class names in `HtmlFormat` (``monoseq-annotation-*`` and
  ``monoseq-margin``).


Version 1.0.0
-------------

Released on July 13th 2013.

- User-definable formatting stylings. This breaks the 0.1.0 API for
  `monoseq.pprint_sequence` (the `mode` argument is superseded by `format`).
- Read sequences from a FASTA file.
- Command line interface.


Version 0.1.0
-------------

Released on July 12th 2013.

First public release.
